### VDownloader
[![Python package](https://github.com/uadson/vdowloader/actions/workflows/build_tests.yml/badge.svg)](https://github.com/uadson/vdowloader/actions/workflows/build_tests.yml)


#### Exemplo de um programa simples para fazer downloads de vídeos ou áudios do Youtube

##### Biblioteca utilizada: pytube

#### 1º passo: Isolar dependências do projeto

    python -m venv .venv


#### 2º passo: Ativar o ambiente virtual

Windows

    .\.venv\Scripts\activate


Linux

    source .venv/bin/activate


#### 3º passo: Instalação

    pip install vdownloader


#### 4º passo: Executando o programa, comando:

    $ vdownloader
